setwd("C:/Users/domen/Desktop/Biostatistica/Meta_hr")
source("C:/Users/domen/Desktop/Biostatistica/pacchetto_funzioni.R")

# Versione codice di chat gpt ---------------------------------------------
library(metafor)
library(readxl)
library(tidyverse)
library(forestplot)

# Carica i dati da file Excel
dati_hr <- read_excel("meta_hr_d.xlsx")

dati_hr$log_hr_os <- log(dati_hr$hr_os)
dati_hr$log_lci <- log(dati_hr$low_ic_os)
dati_hr$log_uci <- log(dati_hr$upper_ic_os)
dati_hr$log_se <- (dati_hr$log_uci - dati_hr$log_lci) / 3.92

# Esegue la meta-analisi utilizzando il modello a effetti casuali (REML)
res <- rma(yi = dati_hr$log_hr_os, slab = dati_hr$name,
           sei = dati_hr$log_se,
           method = "REML",
           test = "adhoc")
weights <- paste0(formatC(weights(res), format="f", digits=1), "%")
weights[weights == "NA%"] <- ""
# Stampa un riepilogo dei risultati
summary(res)
pred <- predict(res, transf=exp, digits=2)
pred
pred <- formatC(c(pred$pred, pred$ci.lb, pred$ci.ub), format="f", digits=2)
k <- nrow(dati_hr)
options(na.action = "na.pass")
weights <- paste0(formatC(weights(res), format="f", digits=1), "%")
weights[weights == "NA%"] <- ""
#par(mar=c(10.8,0,1.3,1.3), mgp=c(3,0.2,0), tcl=-0.2)
tiff("forestplot_d_os.tiff", units = "in", width = 10.5, height = 6, res = 600)
### forest plot with extra annotations
sav <- forest(res, atransf=exp, at=log(c(0.5, 1, 2, 4,8,16)), 
              xlim=c(-18,3),
              xlab="", 
              efac=c(0,4), textpos=c(-18,-4.7), lty=c(1,1,0),
              ilab=cbind(weights),
              refline=NA,
              ilab.xpos=c(-10.8), ilab.pos=2,
              cex=1, header=c("Study","Hazard ratio 95% CI"), mlab="")

segments(sav$xlim[1]+0.5, k+1, sav$xlim[2], k+1, lwd=0.8)
par(xpd=NA)
### add vertical reference line at 0
segments(0, -2, 0, k+1, lwd=0.8)

text(sav$ilab.xpos, k+2, pos=2, c('',"Weights"),font = 2)

#text(sav$textpos[2], k+3, "Hazard ratio", pos=2)

#text(0, k+3, "Hazard ratio")
text(0, k+2, "Hazard ratio 95% CI",font=2)



### first hide the non-bold summary estimate text and then add it back in bold font
text(c(sav$xlim[1],sav$ilab.xpos[c(1,2)]), -1, pos=c(4,2),
     c("Total (95% CI)", "100.0%"),font=2)

rect(sav$textpos[2], -1.5, sav$ilab.xpos[1], -0.5, col="white", border=NA)
text(sav$textpos[2], -1, paste0(pred[1], " [", pred[2], ",  ", pred[3], "]"), pos=2,font=2)
par(cex=sav$cex, font=1)


### add 'Favours caffeine'/'Favours decaf' text below the x-axis
text(log(c(1/7, 4.5)), -3.2, c("","Low D Vitamin 
Worse"), offset=2)

text(sav$xlim[1], -2.9, pos=4, 
     bquote(paste("Heterogeneity: ", "Tau"^2, " = ",
                  .(formatC(res$tau2, digits=2, format="f")),'[0.012,3.2]',
                  "; ", "Chi"^2, " = ",.(formatC(res$QE, digits=2, format="f")),
                  ", df = ", .(res$k - res$p),
                  " (P = 0.012",")")))

text(sav$xlim[1], -3.5, pos=4, 
     bquote(paste(
       I^2, " = ",
       .(formatC(res$I2, digits=0, format="f")),'% [18% ,98%]')))
text(sav$xlim[1], -4.1, pos=4, bquote(paste("Test for overall effect: Z = ",
                                            .(formatC(res$zval, digits=2, format="f")),
                                            " (P = ", .(formatC(res$pval, digits=2, format="f")), ")")))
dev.off()
tiff("funnel_d_os.tiff", units = "in", width = 9, height = 7, res = 600)
funnel(res,atransf = exp)
dev.off()
# FIne grafico ------------------------------------------------------------
dati_hr$log_lci_pfs <- log(dati_hr$low_ic_pfs)
dati_hr$log_uci_pfs <- log(dati_hr$upper_ic_pfs)
dati_hr$log_se_pfs <- (dati_hr$log_uci_pfs - dati_hr$log_lci_pfs) / 3.92
dati_hr<-na.omit(dati_hr)



res <- rma(yi = log(dati_hr$hr_pfs), slab = dati_hr$name,
           sei = dati_hr$log_se_pfs,
           method = "REML",
           test = "adhoc")
weights <- paste0(formatC(weights(res), format="f", digits=1), "%")
weights[weights == "NA%"] <- ""
# Stampa un riepilogo dei risultati
summary(res)
pred <- predict(res, transf=exp, digits=2)
pred
pred <- formatC(c(pred$pred, pred$ci.lb, pred$ci.ub), format="f", digits=2)
k <- nrow(dati_hr)
options(na.action = "na.pass")
weights <- paste0(formatC(weights(res), format="f", digits=1), "%")
weights[weights == "NA%"] <- ""

tiff("forestplot_d_dfs.tiff", units = "in", width = 9, height = 5, res = 600)
### forest plot with extra annotations
sav <- forest(res, atransf=exp, at=log(c(0.5, 1, 2)), 
              xlim=c(-13,3),
              xlab="", 
              efac=c(0,4), textpos=c(-13,-2.7), lty=c(1,1,0),
              ilab=cbind(weights),
              refline=NA,
              ilab.xpos=c(-7.8), ilab.pos=2,
              cex=1, header=c("Study","Hazard ratio 95% CI"), mlab="")

segments(sav$xlim[1]+0.5, k+1, sav$xlim[2], k+1, lwd=0.8)
par(xpd=NA)
### add vertical reference line at 0
segments(0, -2, 0, k+1, lwd=0.8)


text(sav$ilab.xpos, k+2, pos=2, c('',"Weights"),font=2)

#text(sav$textpos[2], k+3, "Hazard ratio", pos=2)

#text(0, k+3, "Hazard ratio")
text(0, k+2, "Hazard ratio 95% CI",font=2)



### first hide the non-bold summary estimate text and then add it back in bold font
text(c(sav$xlim[1],sav$ilab.xpos[c(1,2)]), -1, pos=c(4,2),
     c("Total (95% CI)", "100.0%"),font=2)

rect(sav$textpos[2], -1.5, sav$ilab.xpos[1], -0.5, col="white", border=NA)
text(sav$textpos[2], -1, paste0(pred[1], " [", pred[2], ",  ", pred[3], "]"), pos=2,font=2)
par(cex=sav$cex, font=1)


### add 'Favours caffeine'/'Favours decaf' text below the x-axis
text(log(c(1/7, 4.5)), -3.3, c("","Low D vitamin 
Worse"), offset=2)

text(sav$xlim[1], -1.8, pos=4, 
     bquote(paste("Heterogeneity: ", "Tau"^2, " = ",
                  .(formatC(res$tau2, digits=2, format="f")),'[0.00,0.16]',
                  "; ", "Chi"^2, " = ",.(formatC(res$QE, digits=2, format="f")),
                  ", df = ", .(res$k - res$p),
                  " (P =0.85",")")))

text(sav$xlim[1], -2.5, pos=4, 
     bquote(paste(
       I^2, " = ",
       .(formatC(res$I2, digits=0, format="f")),'% [0% ,80%]')))
text(sav$xlim[1], -3.2, pos=4, bquote(paste("Test for overall effect: Z = ",
                                            .(formatC(res$zval, digits=2, format="f")),
                                            " (P = ", .(formatC(res$pval, digits=2, format="f")), ")")))
confint(res,digits = 2)
dev.off()
tiff("funnel_d_pfs.tiff", units = "in", width = 9, height = 7, res = 600)
funnel(res,label = F,atransf = exp)
dev.off()
